summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit11ca4665181f6e000f6c9b0b5e30a4fa55f268d6 (patch)
treeac0c45e732b5e46bdd65ae75ab93e348629a34a8
parent5188f17bef778f83403647192cd9bbe2a23d586b (diff)
downloadkcpuload-11ca4665.tar.gz
kcpuload-11ca4665.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kcpuload@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--kcpuload/kcpuload/icontoggleaction.cpp16
-rw-r--r--kcpuload/kcpuload/icontoggleaction.h8
-rw-r--r--kcpuload/kcpuload/kcpudock.cpp4
-rw-r--r--kcpuload/kcpuload/kcpudock.h2
-rw-r--r--kcpuload/kcpuload/kcpuload.cpp4
-rw-r--r--kcpuload/kcpuload/kcpuload.h2
-rw-r--r--kcpuload/kcpuload/speeddialog.cpp4
-rw-r--r--kcpuload/kcpuload/speeddialog.h2
-rw-r--r--kcpuload/kcpuload/statdock.cpp6
-rw-r--r--kcpuload/kcpuload/statdock.h8
-rw-r--r--kcpuload/kcpuload/statpopup.cpp4
-rw-r--r--kcpuload/kcpuload/statpopup.h2
12 files changed, 31 insertions, 31 deletions
diff --git a/kcpuload/kcpuload/icontoggleaction.cpp b/kcpuload/kcpuload/icontoggleaction.cpp
index 3c39554..a7d7625 100644
--- a/kcpuload/kcpuload/icontoggleaction.cpp
+++ b/kcpuload/kcpuload/icontoggleaction.cpp
@@ -17,9 +17,9 @@ IconToggleAction::IconToggleAction(
const TQString& useTextUnchecked, const TQString& useIconUnchecked,
const TQString& useTextChecked, const TQString& useIconChecked,
const KShortcut& cut, const TQObject* receiver, const char* slot,
- TQObject* tqparent, const char* name) :
+ TQObject* parent, const char* name) :
KToggleAction(useTextUnchecked, useIconUnchecked, cut, receiver,
- slot, tqparent, name),
+ slot, parent, name),
textChecked(useTextChecked), textUnchecked(useTextUnchecked),
iconChecked(useIconChecked), iconUnchecked(useIconUnchecked) {
}
@@ -27,9 +27,9 @@ IconToggleAction::IconToggleAction(
IconToggleAction::IconToggleAction(const TQString& useText,
const TQString& useIconUnchecked, const TQString& useIconChecked,
const KShortcut& cut, const TQObject* receiver, const char* slot,
- TQObject* tqparent, const char* name) :
+ TQObject* parent, const char* name) :
KToggleAction(useText, useIconUnchecked, cut, receiver,
- slot, tqparent, name),
+ slot, parent, name),
textChecked(useText), textUnchecked(useText),
iconChecked(useIconChecked), iconUnchecked(useIconUnchecked) {
}
@@ -37,16 +37,16 @@ IconToggleAction::IconToggleAction(const TQString& useText,
IconToggleAction::IconToggleAction(
const TQString& useTextUnchecked, const TQString& useIconUnchecked,
const TQString& useTextChecked, const TQString& useIconChecked,
- const KShortcut& cut, TQObject* tqparent, const char* name) :
- KToggleAction(useTextUnchecked, useIconUnchecked, cut, tqparent, name),
+ const KShortcut& cut, TQObject* parent, const char* name) :
+ KToggleAction(useTextUnchecked, useIconUnchecked, cut, parent, name),
textChecked(useTextChecked), textUnchecked(useTextUnchecked),
iconChecked(useIconChecked), iconUnchecked(useIconUnchecked) {
}
IconToggleAction::IconToggleAction(const TQString& useText,
const TQString& useIconUnchecked, const TQString& useIconChecked,
- const KShortcut& cut, TQObject* tqparent, const char* name) :
- KToggleAction(useText, useIconUnchecked, cut, tqparent, name),
+ const KShortcut& cut, TQObject* parent, const char* name) :
+ KToggleAction(useText, useIconUnchecked, cut, parent, name),
textChecked(useText), textUnchecked(useText),
iconChecked(useIconChecked), iconUnchecked(useIconUnchecked) {
}
diff --git a/kcpuload/kcpuload/icontoggleaction.h b/kcpuload/kcpuload/icontoggleaction.h
index 9758291..169fc6b 100644
--- a/kcpuload/kcpuload/icontoggleaction.h
+++ b/kcpuload/kcpuload/icontoggleaction.h
@@ -32,19 +32,19 @@ class IconToggleAction : public KToggleAction {
const TQString& useTextUnchecked, const TQString& useIconUnchecked,
const TQString& useTextChecked, const TQString& useIconChecked,
const KShortcut& cut, const TQObject* receiver, const char* slot,
- TQObject* tqparent, const char* name = 0);
+ TQObject* parent, const char* name = 0);
IconToggleAction(const TQString& useText,
const TQString& useIconUnchecked, const TQString& useIconChecked,
const KShortcut& cut, const TQObject* receiver, const char* slot,
- TQObject* tqparent, const char* name = 0);
+ TQObject* parent, const char* name = 0);
IconToggleAction(
const TQString& useTextUnchecked, const TQString& useIconUnchecked,
const TQString& useTextChecked, const TQString& useIconChecked,
- const KShortcut& cut = KShortcut(), TQObject* tqparent = 0,
+ const KShortcut& cut = KShortcut(), TQObject* parent = 0,
const char* name = 0);
IconToggleAction(const TQString& useText,
const TQString& useIconUnchecked, const TQString& useIconChecked,
- const KShortcut& cut = KShortcut(), TQObject* tqparent = 0,
+ const KShortcut& cut = KShortcut(), TQObject* parent = 0,
const char* name = 0);
/**
diff --git a/kcpuload/kcpuload/kcpudock.cpp b/kcpuload/kcpuload/kcpudock.cpp
index 158e88b..9385f73 100644
--- a/kcpuload/kcpuload/kcpudock.cpp
+++ b/kcpuload/kcpuload/kcpudock.cpp
@@ -15,8 +15,8 @@
#include <klocale.h>
-KCPUDock::KCPUDock(int whichCPU, StatPopup *tqparent, const char *name) :
- StatDock(whichCPU, i18n("C"), tqparent, name) {
+KCPUDock::KCPUDock(int whichCPU, StatPopup *parent, const char *name) :
+ StatDock(whichCPU, i18n("C"), parent, name) {
}
void KCPUDock::setCPULabel(int set) {
diff --git a/kcpuload/kcpuload/kcpudock.h b/kcpuload/kcpuload/kcpudock.h
index 3318ec6..f96e411 100644
--- a/kcpuload/kcpuload/kcpudock.h
+++ b/kcpuload/kcpuload/kcpudock.h
@@ -25,7 +25,7 @@ public:
/**
* Constructor.
*/
- KCPUDock(int whichDock, StatPopup *tqparent = 0, const char *name = 0);
+ KCPUDock(int whichDock, StatPopup *parent = 0, const char *name = 0);
/**
* Sets the label for this diagram. The label will reflect which
diff --git a/kcpuload/kcpuload/kcpuload.cpp b/kcpuload/kcpuload/kcpuload.cpp
index 18971fe..500b18a 100644
--- a/kcpuload/kcpuload/kcpuload.cpp
+++ b/kcpuload/kcpuload/kcpuload.cpp
@@ -21,8 +21,8 @@
#include <klocale.h>
#include <kpopupmenu.h>
-KCPULoad::KCPULoad(TQWidget *tqparent, const char *name) :
- StatPopup(true, tqparent, name) {
+KCPULoad::KCPULoad(TQWidget *parent, const char *name) :
+ StatPopup(true, parent, name) {
// Create the /proc reading class and check for SMP.
proc = new KCPUProc();
supportSMP = proc->hasSMP();
diff --git a/kcpuload/kcpuload/kcpuload.h b/kcpuload/kcpuload/kcpuload.h
index b784632..a717224 100644
--- a/kcpuload/kcpuload/kcpuload.h
+++ b/kcpuload/kcpuload/kcpuload.h
@@ -30,7 +30,7 @@ public:
/**
* Constructor and destructor.
*/
- KCPULoad(TQWidget *tqparent = 0, const char *name = 0);
+ KCPULoad(TQWidget *parent = 0, const char *name = 0);
~KCPULoad();
public slots:
diff --git a/kcpuload/kcpuload/speeddialog.cpp b/kcpuload/kcpuload/speeddialog.cpp
index f72d3d9..33c7091 100644
--- a/kcpuload/kcpuload/speeddialog.cpp
+++ b/kcpuload/kcpuload/speeddialog.cpp
@@ -25,8 +25,8 @@ static int stockSpeed[] = {
3000, 4000, 5000, 0
};
-SpeedDialog::SpeedDialog(int defaultSpeed, TQWidget* tqparent) :
- KDialogBase(tqparent, "speed dialog", true,
+SpeedDialog::SpeedDialog(int defaultSpeed, TQWidget* parent) :
+ KDialogBase(parent, "speed dialog", true,
i18n("Select Speed"), Ok|Cancel, Ok),
speed(defaultSpeed) {
TQHBox* page = makeHBoxMainWidget();
diff --git a/kcpuload/kcpuload/speeddialog.h b/kcpuload/kcpuload/speeddialog.h
index aade140..e2132d1 100644
--- a/kcpuload/kcpuload/speeddialog.h
+++ b/kcpuload/kcpuload/speeddialog.h
@@ -27,7 +27,7 @@ class SpeedDialog : public KDialogBase {
/**
* Constructor.
*/
- SpeedDialog(int defaultSpeed, TQWidget* tqparent);
+ SpeedDialog(int defaultSpeed, TQWidget* parent);
/**
* Returns the speed currently selected in the dialog.
diff --git a/kcpuload/kcpuload/statdock.cpp b/kcpuload/kcpuload/statdock.cpp
index e28f15e..5622144 100644
--- a/kcpuload/kcpuload/statdock.cpp
+++ b/kcpuload/kcpuload/statdock.cpp
@@ -33,8 +33,8 @@ const TQColor StatDock::colorBlack(0, 0, 0);
#define SOFT_STEP 3
StatDock::StatDock(int whichDock, const TQString& useLabel,
- StatPopup *tqparent, const char *name) :
- KSystemTray(tqparent,name),
+ StatPopup *parent, const char *name) :
+ KSystemTray(parent,name),
label(useLabel),
bufUpper(0),
bufLower(0),
@@ -48,7 +48,7 @@ StatDock::StatDock(int whichDock, const TQString& useLabel,
bufUpper[i] = bufLower[i] = 0;
// Initialise the display.
- tqparent->initDock(this, contextMenu(), whichDock);
+ parent->initDock(this, contextMenu(), whichDock);
setBackgroundColor(colorBlack);
resize(DOCK_SIZE, DOCK_SIZE);
show();
diff --git a/kcpuload/kcpuload/statpopup.cpp b/kcpuload/kcpuload/statpopup.cpp
index 7740444..baf5d76 100644
--- a/kcpuload/kcpuload/statpopup.cpp
+++ b/kcpuload/kcpuload/statpopup.cpp
@@ -59,8 +59,8 @@ void StatPopup::Reading::Init(int which, StatPopup* popup)
}
-StatPopup::StatPopup(bool useSupportSplit, TQWidget *tqparent, const char *name) :
- TQWidget(tqparent, name, TQt::WStyle_Customize | TQt::WStyle_NoBorder |
+StatPopup::StatPopup(bool useSupportSplit, TQWidget *parent, const char *name) :
+ TQWidget(parent, name, TQt::WStyle_Customize | TQt::WStyle_NoBorder |
TQt::WStyle_StaysOnTop | TQt::WDestructiveClose | TQt::WType_TopLevel),
supportSplit(useSupportSplit) {
// Window management.
diff --git a/kcpuload/kcpuload/statpopup.h b/kcpuload/kcpuload/statpopup.h
index 35a8f43..b39986e 100644
--- a/kcpuload/kcpuload/statpopup.h
+++ b/kcpuload/kcpuload/statpopup.h
@@ -65,7 +65,7 @@ public:
* any configuration information. See the general class notes also
* for a list of other routines this constructor will not call.
*/
- StatPopup(bool useSupportSplit, TQWidget *tqparent = 0, const char *name = 0);
+ StatPopup(bool useSupportSplit, TQWidget *parent = 0, const char *name = 0);
~StatPopup();
/**
diff --git a/kcpuload/kcpuload/statdock.h b/kcpuload/kcpuload/statdock.h
index 072c2c5..03d06df 100644
--- a/kcpuload/kcpuload/statdock.h
+++ b/kcpuload/kcpuload/statdock.h
@@ -29,7 +29,7 @@ class StatPopup;
* with the upper readings shown above the lower readings. When diagram
* splitting is switched off, only the upper readings will be displayed.
*
* The tqparent window of a StatDock must be a StatPopup, which provides
* all of the actions in this window's context menu.
*/
class StatDock : public KSystemTray {
@@ -59,14 +59,14 @@ public:
/**
* Constructor and destructor.
*
* Note that the constructor will call tqparent->initDock().
*
* Parameter whichDock must be 0 or 1 to specify whether this dock
* will become dock[0] or dock[1] in the given StatPopup tqparent.
* Parameter useLabel should contain the label that will be drawn on
* the diagram if labelling is enabled.
*/
- StatDock(int whichDock, const TQString& useLabel, StatPopup *tqparent,
+ StatDock(int whichDock, const TQString& useLabel, StatPopup *parent,
const char *name = 0);
~StatDock();
@@ -29,7 +29,7 @@ class StatPopup;
* splitting is switched off, only the upper readings will be displayed.
*
- * The tqparent window of a StatDock must be a StatPopup, which provides
+ * The parent window of a StatDock must be a StatPopup, which provides
* all of the actions in this window's context menu.
*/
@@ -59,14 +59,14 @@ public:
* Constructor and destructor.
*
- * Note that the constructor will call tqparent->initDock().
+ * Note that the constructor will call parent->initDock().
*
* Parameter whichDock must be 0 or 1 to specify whether this dock
@@ -59,14 +59,14 @@ public:
*
* Parameter whichDock must be 0 or 1 to specify whether this dock
- * will become dock[0] or dock[1] in the given StatPopup tqparent.
+ * will become dock[0] or dock[1] in the given StatPopup parent.
* Parameter useLabel should contain the label that will be drawn on
* the diagram if labelling is enabled.